@@ -2,7 +2,7 @@
 
 package TPath::Grammar;
 {
-  $TPath::Grammar::VERSION = '1.003';
+  $TPath::Grammar::VERSION = '1.004';
 }
 
 use v5.10;
@@ -1290,7 +1290,16 @@ sub clean_escapes {
         my $i = index $m, '\\';
         if ( $i > -1 ) {
             my $prefix = substr $m, 0, $i;
-            $prefix .= substr $m, $i + 1, 1;
+            my $c = substr $m, $i + 1, 1;
+            for ($c) {
+                when ('b') { $c = "\b" }
+                when ('f') { $c = "\f" }
+                when ('n') { $c = "\012" }
+                when ('r') { $c = "\015" }
+                when ('t') { $c = "\t" }
+                when ('v') { $c = "\013" }
+            }
+            $prefix .= $c;
             $m = substr $m, $i + 2;
             $r .= $prefix;
             redo;
@@ -1346,7 +1355,7 @@ TPath::Grammar - parses TPath expressions into ASTs
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
